@@ -2,26 +2,26 @@ import datetime
 
 from django import template
 
-from commons.python.utils import Format
+from commons.python import formatter
 
 register = template.Library()
 
 
 @register.filter(name='decimalf')
 def format_decimal(val, decimal_places=2):
-    return Format.decimal(val, decimal_places)
+    return formatter.decimal(val, decimal_places)
 
 
 @register.filter(name='currencyf')
 def format_currency(val):
-    return Format.price(val)
+    return formatter.price(val)
 
 
 @register.filter(name='datef')
 def date_format(date: datetime):
-    return Format.date(date)
+    return formatter.date_format(date)
 
 
 @register.filter(name='datetimef')
 def date_time_format(date_time: datetime):
-    return Format.date_time(date_time)
+    return formatter.date_time(date_time)
